/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	"flag"
	"gitlab.nrao.edu/ssa/gocapo/helpers"
	"os"
	"ssa/mod_analyst/pkg/db"
)

func main() {
	// user args
	var user db.UserInfo
	var isRemove bool
	var isUpdate bool

	// DB connection args
	var connectionInfo = initDbInfo()

	// Get user properties
	flag.StringVar(&user.Group, "group", "Stage 1", "When adding a user, makes them part of the relevant QA group (by default they are added to the Stage 1 group)")
	flag.StringVar(&user.Name, "name", "", "The full name of the QA reviewer to be added, use quotes for the first and last name (e.g. -name 'First Last')")
	flag.StringVar(&user.Email, "email", "", "The email of the QA reviewer to be added")
	flag.BoolVar(&isRemove, "rm", false, "Remove the user from the database")
	flag.BoolVar(&isUpdate, "up", false, "Update a user already in the database. Updatable fields are email and availability only. To change an existing user's group add a new record.")
	flag.BoolVar(&user.IsUnavailable, "unavailable", false, "Mark the user as unavailable, must be used with '-up' flag")
	flag.BoolVar(&user.IsAvailable, "available", false, "Mark the user as available, must be used with '-up' flag")

	// Get DB connection args
	flag.StringVar(&connectionInfo.AltCapoPath, "path", helpers.DefaultCapoPath, "Path to the properties file with the login details for the database")

	flag.StringVar(&connectionInfo.Profile, "profile", os.Getenv("CAPO_PROFILE"), "CAPO Profile to use for database connection, defaults to CAPO_PROFILE of the current environment")
	flag.Parse()

	// Make sure name is given
	if len(user.Name) == 0 {
		flag.Usage()
		return
	}

	if isRemove {
		db.RemoveUser(user, connectionInfo)
	} else if isUpdate {
		db.UpdateUser(user, connectionInfo)
	} else {
		db.AddUser(user, connectionInfo)
	}
}

func initDbInfo() db.DbInfo {
	return db.DbInfo{
		Host:        "",
		Port:        0,
		User:        "",
		Password:    "",
		Dbname:      "",
		Profile:     "",
		IsSsl:       false,
		AltCapoPath: "",
	}
}
